Examples
=========

* `making arrays <_static/make_object_arrays_demo.html>`_: manually creating nsn stimuluss and exporting picture file
* `random arrays <_static/pynsn_demo.html>`_: Creating random nsn stimuli
* matching visual features
* data base, sequences
* `Euro flag example <_static/euro_flag_demo.html>`_: using pictures as objects in array
